﻿using System;
using System.Data.SqlClient;
using System.Diagnostics;
using System.IO;
using System.Windows.Forms;
using System.Xml;

namespace PosSqlCheck
{
    static class Program
    {
        private readonly static string _programFilesX86 = Environment.GetFolderPath(Environment.SpecialFolder.ProgramFilesX86);
        private readonly static string _programData = Environment.GetFolderPath(Environment.SpecialFolder.CommonApplicationData);
        private readonly static string _sambaProgramData = Path.Combine(_programData, "SambaPOS", "SambaPOS5");
        private readonly static string _sambaLocalSettings = Path.Combine(_sambaProgramData, "SambaSettings.txt");
        private readonly static string _sambaProgramFiles = Path.Combine(_programFilesX86, "SambaPOS5");

        [STAThread]
        static void Main()
        {
            var connectionString = GetConnectionString();

            try
            {
                using (var connection = new SqlConnection(connectionString))
                {
                    connection.Open();

                    using (var command = new SqlCommand("SELECT DB_NAME()", connection))
                    {
                        command.ExecuteScalar();
                    }
                }
            }
            catch (Exception ex)
            {
                Application.EnableVisualStyles();
                Application.SetCompatibleTextRenderingDefault(false);
                Application.Run(new Form1(ex.Message));

                return;
            }

            var pInfo = new ProcessStartInfo { FileName = Path.Combine(_sambaProgramFiles, "Samba.Presentation.exe") };

            Process.Start(pInfo);
        }

        private static string GetConnectionString()
        {
            var xml = new XmlDocument();
            xml.Load(_sambaLocalSettings);
            var root = xml.DocumentElement;

            if (root.SelectSingleNode("ConnectionString") != null)
            {
                return root.SelectSingleNode("ConnectionString").InnerText;
            }

            return null;
        }
    }
}
